[gnus git] branch master updated: n0-17-484-g1703ba2 =1= gnus-sum.el (gnus-summary-mode): Don't make bidi-paragraph-direction bound in old Emacsen and XEmacsen.

Katsumi Yamaoka <[email protected]>
Newsgroups gmane.emacs.gnus.cvs
Message-ID <[email protected]>
       via  1703ba2ba72f80f3bf71225c8a6566ffc2460d76 (commit)
      from  cc7e694d0a594d0c89d9b8611123c98f502a5e27 (commit)


- Log -----------------------------------------------------------------
commit 1703ba2ba72f80f3bf71225c8a6566ffc2460d76
Author: Katsumi Yamaoka <[email protected]>
Date:   Thu Jan 26 23:01:59 2012 +0000

    gnus-sum.el (gnus-summary-mode): Don't make bidi-paragraph-direction bound in old Emacsen and XEmacsen.

diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 346d1bf..1a5dc6a 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,8 @@
+2012-01-26  Katsumi Yamaoka  <[email protected]>
+
+	* gnus-sum.el (gnus-summary-mode): Don't make bidi-paragraph-direction
+	bound in old Emacsen and XEmacsen.
+
 2012-01-26  Nick Alcock  <[email protected]>  (tiny change)
 
 	* gnus.el (gnus-group-find-parameter): Check for liveness of the
diff --git a/lisp/gnus-sum.el b/lisp/gnus-sum.el
index 2097dfb..bbb4c46 100644
--- a/lisp/gnus-sum.el
+++ b/lisp/gnus-sum.el
@@ -3060,8 +3060,6 @@ When FORCE, rebuild the tool bar."
 (defvar bookmark-make-record-function)
 
 
-(defvar bidi-paragraph-direction)
-
 (defun gnus-summary-mode (&optional group)
   "Major mode for reading articles.
 
@@ -3100,8 +3098,9 @@ The following commands are available:
   (setq buffer-read-only t		;Disable modification
 	show-trailing-whitespace nil)
   (setq truncate-lines t)
-  ;; Force paragraph direction to be left-to-right.
-  (setq bidi-paragraph-direction 'left-to-right)
+  ;; Force paragraph direction to be left-to-right.  Don't make it
+  ;; bound in old Emacsen and XEmacsen.
+  (set (make-local-variable 'bidi-paragraph-direction) 'left-to-right)
   (add-to-invisibility-spec '(gnus-sum . t))
   (gnus-summary-set-display-table)
   (gnus-set-default-directory)

-----------------------------------------------------------------------
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we listed those
revisions in full, above.

Summary of changes:
 lisp/ChangeLog   |    5 +++++
 lisp/gnus-sum.el |    7 +++----
 2 files changed, 8 insertions(+), 4 deletions(-)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnus Project".

The branch, master has been updated


hooks/post-receive
-- 
Gnus Project
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.